@@ -2,6 +2,7 @@
 from requests import Request, Session
 from itertools import islice
 import sys
+import mimetypes
 sys.path.append( '.\\seams\\' )
 sys.path.append( '.\\' )
 from seams.exceptions import SeamsException, SeamsAPIException
@@ -9,7 +10,6 @@ import json
 import msal
 import os
 
-
 class Seams(object):
     '''
     A Python interface for the Seams API
@@ -25,12 +25,12 @@ class Seams(object):
         self.connected = False
 
 
-    def connect(self, 
+    def connect(self,
                 secret,
                 app_id,
                 tenant_id):
         '''
-        Connect to the Seams API 
+        Connect to the Seams API
         :param secret:
             A secret given by RJLG staff to access the Seams SDK  **REQUIRED**
         :param app_id:
@@ -44,19 +44,18 @@ class Seams(object):
         self.app_id = app_id
         self.tenant_id = tenant_id
         app = msal.ConfidentialClientApplication(
-                app_id, 
+                app_id,
                 authority="https://login.microsoftonline.com/{}".format(tenant_id),
                 client_credential=secret)
         result = None
-        result = app.acquire_token_silent(scopes=["https://partiddevb2c.onmicrosoft.com/{}/.default".format(app_id)], account=None)
-
+        result = app.acquire_token_silent(scopes=["api://{}/access_as_user".format(app_id)], account=None)
         if not result:
-            result = app.acquire_token_for_client(scopes=["https://partiddevb2c.onmicrosoft.com/{}/.default".format(app_id)])
-        if 'error' in result:
+            result = app.acquire_token_for_client(scopes=["api://{}/.default".format(app_id)])
+        if "error" in result:
             print("Error connecting with given credentials")
-            raise SeamsAPIException(result['error_description'])
+            raise SeamsAPIException(result["error_description"])
         else:
-            self.bearer = result['access_token']
+            self.bearer = result["access_token"]
             self.connected = True
 
 
@@ -198,12 +197,13 @@ class Seams(object):
         '''
         body = {}
         if attributes:
-            body = self.__properties_formatter(vertex_label, attributes, vertex_name=vertex_name)
+            body = self.__properties_formatter(vertex_label, {"name":vertex_name}, vertex_name=vertex_name)
         try:
+            response = self.__http_request('POST', '{}/tenant/{}/vertex/create'.format(self.URL, tenant_id), content='application/json', data=body)
             for attributeChunk in self.__chunk_attributes(attributes, 10):
                 body = self.__properties_formatter(vertex_label, attributeChunk)
-                response = self.__http_request('POST', '{}/tenant/{}/vertex/create'.format(self.URL, tenant_id), content='application/json', data=body)
-            return response.json()
+                updateResponse = self.__http_request('PUT', '{}/tenant/{}/vertex/update/{}'.format(self.URL, tenant_id, response.json()['id']), content='application/json', data=body)
+            return updateResponse.json()
         except:
             raise SeamsAPIException(response.text)
 
@@ -233,11 +233,17 @@ class Seams(object):
         try:
             response = self.__http_request('GET', '{}/tenant/{}/vertices/{}'.format(self.URL, tenant_id, vertex_label))
             
-            if(not response.json()["count"]):
+            existingVertex = None
+
+            for vertex in response.json()["vertices"]:
+                if vertex["name"] == vertex_name:
+                    existingVertex = vertex
+            
+            if(existingVertex):
+                vertex_id = existingVertex["id"]
+            else:
                 response = self.__http_request('POST', '{}/tenant/{}/vertex/create'.format(self.URL, tenant_id), content='application/json', data=body)
                 vertex_id = response.json()["id"]
-            else:
-                vertex_id = response.json()["vertices"][0]["id"]
             
             for attributeChunk in self.__chunk_attributes(attributes, 10):
                 body = self.__properties_formatter(vertex_label, attributeChunk)
@@ -404,7 +410,10 @@ class Seams(object):
         upload_list = []
         for item in filenames:
             body = {'upload_preset': item, 'fileType': file_type, 'caption': caption}
-            files = {'file':(item, open(item, 'rb'))}
+            mimetype = mimetypes.guess_type(item)[0]
+            if mimetype == "application/vnd.ms-excel":
+                mimetype = "text/csv"
+            files = {'file': (item, open(item, 'rb'), mimetype)}
 
             try:
                 response = self.__http_request('POST', '{}/tenant/{}/upload/file'.format(self.URL, tenant_id), files=files, data=body)
